ChannelTimeoutException class

Exception thrown when a platform channel operation times out.

Inheritance

Constructors

ChannelTimeoutException(String message, [String? details, Duration? timeout])
Creates a new channel timeout exception.
const

Properties

details String?
Additional error details.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
message String
The error message.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timeout Duration?
The timeout duration that was exceeded.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited